@@ -39,6 +39,6 @@ void image_cache_destroy(ImageCache* image_cache);
 
 /* Member functions */
 
-GdkPixbuf* image_cache_load_image(ImageCache* image_cache, Http* http, gchar* url);
+GdkPixbuf* image_cache_load_image(ImageCache* image_cache, MicrofeedHttp* http, gchar* url);
 
 #endif
