@@ -613,7 +613,7 @@ static void parse_json_item_comment(JsonObject* json, ViewItem* item, MicrofeedH
 		s = json_object_get_string(object);
 		g_string_append(string, " on ");
 		if (strlen(s) > 20) {
-			s = g_markup_escape_text(s, 20);
+			s = g_markup_escape_text(s, g_utf8_offset_to_pointer(s, 20) - s);
 			g_string_append(string, s);
 			g_string_append(string, "...");
 		} else {
