@@ -35,18 +35,18 @@ typedef struct {
 } TwitterData;
 
 static gint compare_item_nicks(gconstpointer a, gconstpointer b);
-static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, Http* http, TwitterMessageType type, time_t delta);
+static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, MicrofeedHttp* http, TwitterMessageType type, time_t delta);
 static void on_contact_clicked_callback(View* view, ViewItem* item, gboolean was_avatar);
 static void on_tweet_menu_item_activate(GtkMenuItem* menu_item, gpointer user_data);
 static void on_item_destroy_callback(ViewItem* item);
 static void on_tweet_clicked_callback(View* view, ViewItem* item, gboolean was_avatar);
-static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http, TwitterMessageType type, time_t delta);
-static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
-static gboolean update_generic_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, MicrofeedHttp* http, TwitterMessageType type, time_t delta);
+static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
+static gboolean update_generic_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 static void update_tweet_view(View* view);
-static gboolean update_tweet_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static gboolean update_tweet_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 static void update_user_view(View* view);
-static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data);
+static gboolean update_user_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data);
 
 ViewItemSource twitter_item_source = {
 	"twitter",
@@ -69,7 +69,7 @@ static ViewItemClass contact_item_class = {
 	on_contact_clicked_callback,  NULL
 };
 
-gboolean twitter_handle_marked_item(ViewAddingSession* session, Http* http, gchar* unique_id, gchar* url) {
+gboolean twitter_handle_marked_item(ViewAddingSession* session, MicrofeedHttp* http, gchar* unique_id, gchar* url) {
 	gboolean retvalue = FALSE;
 	gchar* name = NULL;
 	gchar* password = NULL;
@@ -82,11 +82,11 @@ gboolean twitter_handle_marked_item(ViewAddingSession* session, Http* http, gcha
 	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && *password) {
 		userpass = g_strdup_printf("%s:%s", name, password);
-		if ((feed = http_get_json_object(http, real_url))) {
-			http_set_basic_authentication(http, NULL);
+		if ((feed = microfeed_http_get_json_object(http, real_url))) {
+			microfeed_http_set_basic_authentication(http, NULL);
 
-			if (http_get_server_time(http)) {
-				delta = http_get_server_time(http) - http_get_reply_start_time(http);
+			if (microfeed_http_get_server_time(http)) {
+				delta = microfeed_http_get_server_time(http) - microfeed_http_get_reply_start_time(http);
 			} else {
 				delta = 0;
 			}
@@ -95,7 +95,7 @@ gboolean twitter_handle_marked_item(ViewAddingSession* session, Http* http, gcha
 			}
 			json_object_put(feed);
 		} else {
-			http_set_basic_authentication(http, NULL);
+			microfeed_http_set_basic_authentication(http, NULL);
 		}
 	}
 	g_free(name);
@@ -107,7 +107,7 @@ gboolean twitter_handle_marked_item(ViewAddingSession* session, Http* http, gcha
 
 gboolean twitter_send(const gchar* text) {
 	gboolean retvalue = FALSE;
-	Http* http;
+	MicrofeedHttp* http;
 	gchar* name = NULL;
 	gchar* password = NULL;
 	gchar* userpass;
@@ -115,22 +115,22 @@ gboolean twitter_send(const gchar* text) {
 	gchar* s;
 	gchar* data;
 	
-	if (http_make_connected() && (http = http_new())) {
+	if (network_make_connected() && (http = microfeed_http_new())) {
 		if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 		    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && *password) {
 			userpass = g_strconcat(name, ":", password, NULL);
-			http_set_basic_authentication(http, userpass);
+			microfeed_http_set_basic_authentication(http, userpass);
 			g_free(userpass);
 			
-			s = http_url_encode(http, text);
+			s = microfeed_http_url_encode(http, text);
 			data = g_strconcat("status=", s, "&source=mauku", NULL);
-			http_free(http, s);
-			if ((object = http_post_json_object(http, "http://twitter.com/statuses/update.json", data))) {
+			microfeed_http_free_string(http, s);
+			if ((object = microfeed_http_post_json_object(http, "http://twitter.com/statuses/update.json", data))) {
 				retvalue = TRUE;
 			}
 			g_free(data);
 		}
-		http_destroy(http);
+		microfeed_http_free(http);
 	}
 	
 	g_free(name);
@@ -148,7 +148,7 @@ void twitter_update_contacts_view(View* view) {
 	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && password) {
 		userpass = g_strconcat(name, ":", password, NULL);
-		backend_start_update(view, "http://twitter.com/statuses/friends.json", userpass, &twitter_item_source, TRUE, update_contacts_view_callback, NULL);
+		backend_start_update(view, "http://twitter.com/statuses/friends.json", userpass, &twitter_item_source, TRUE, update_contacts_view_callback, NULL, NULL);
 		g_free(userpass);
 	}
 	
@@ -157,7 +157,7 @@ void twitter_update_contacts_view(View* view) {
 }
 
 void twitter_update_explore_view(View* view) {
-	backend_start_update(view, "http://twitter.com/statuses/public_timeline.json", NULL, &twitter_item_source, FALSE, update_generic_view_callback, NULL);
+	backend_start_update(view, "http://twitter.com/statuses/public_timeline.json", NULL, &twitter_item_source, FALSE, update_generic_view_callback, NULL, NULL);
 }
 
 void twitter_update_generic_view(View* view) {
@@ -168,7 +168,7 @@ void twitter_update_generic_view(View* view) {
 	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && *password) {
 		userpass = g_strdup_printf("%s:%s", name, password);
-		backend_start_update(view, (gchar*)view_get_user_data(view, "twitter:url"), userpass, &twitter_item_source, TRUE, update_generic_view_callback, NULL);
+		backend_start_update(view, (gchar*)view_get_user_data(view, "twitter:url"), userpass, &twitter_item_source, TRUE, update_generic_view_callback, NULL, NULL);
 		g_free(userpass);
 	}
 	
@@ -180,7 +180,7 @@ static gint compare_item_nicks(gconstpointer a, gconstpointer b) {
 	return strcmp(((ViewItem*)a)->unique_id, ((ViewItem*)b)->unique_id);
 }
 
-static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, Http* http, TwitterMessageType type, time_t delta) {
+static gchar* handle_json_item(JsonObject* json, ViewAddingSession* session, MicrofeedHttp* http, TwitterMessageType type, time_t delta) {
 	gboolean valid;
 	ViewItem* item;
 	gchar* unique_id;
@@ -292,7 +292,7 @@ static void on_tweet_clicked_callback(View* view, ViewItem* item, gboolean was_a
 	view_start_update(new_view, TRUE);
 }
 
-static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http, TwitterMessageType type, time_t delta) {
+static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, MicrofeedHttp* http, TwitterMessageType type, time_t delta) {
 	ViewItem* item;
 	GString* string;
 	GString* speech;
@@ -363,7 +363,7 @@ static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http,
 	g_string_append(string, " in Twitter ");
 
 	if ((object = json_object_object_get(json, "created_at"))) {
-		item->timestamp = http_parse_date(http, json_object_get_string(object)) - delta;
+		item->timestamp = microfeed_http_parse_date(http, json_object_get_string(object)) - delta;
 	} else {
 		item->timestamp = time(NULL) - delta;
 	}
@@ -376,7 +376,7 @@ static ViewItem* parse_json_item(JsonObject* json, gchar* unique_id, Http* http,
 	return item;
 }
 
-static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* contacts, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonObject* contacts, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	ViewItem* item;
 	GList* list;
 	GList* list_item;
@@ -394,7 +394,7 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 	
 		return FALSE;
 	}
-	http_set_basic_authentication(http, NULL);
+	microfeed_http_set_basic_authentication(http, NULL);
 
 	list = NULL;
 	for (i = 0; i < json_object_array_length(contacts); i++) {
@@ -430,7 +430,7 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 				g_free(s);
 			}
 			if ((object = json_object_object_get(status, "created_at"))) {
-				item->timestamp = http_parse_date(http, json_object_get_string(object)) - delta;
+				item->timestamp = microfeed_http_parse_date(http, json_object_get_string(object)) - delta;
 			} else {
 				item->timestamp = time(NULL) - delta;
 			}
@@ -473,7 +473,7 @@ static gboolean update_contacts_view_callback(ViewAddingSession* session, JsonOb
 	return TRUE;
 }
 
-static gboolean update_generic_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_generic_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	gboolean retvalue = TRUE;
 	JsonObject* json;
 	int i = 0;
@@ -483,7 +483,7 @@ static gboolean update_generic_view_callback(ViewAddingSession* session, JsonObj
 		if (!(type = (TwitterMessageType)view_get_user_data(view_adding_session_get_view(session), "twitter:type"))) {
 			type = TWITTER_ITEM_TYPE_TWEET;
 		}
-		http_set_basic_authentication(http, NULL);
+		microfeed_http_set_basic_authentication(http, NULL);
 		for (i = 0; i < json_object_array_length(feed); i++) {
 			if (!(json = json_object_array_get_idx(feed, i))) {
 				retvalue = FALSE;
@@ -509,7 +509,7 @@ static void update_tweet_view(View* view) {
 	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && *password) {
 		userpass = g_strdup_printf("%s:%s", name, password);
-		backend_start_update(view, view_get_unique_id(view), userpass, &twitter_item_source, TRUE, update_tweet_view_callback, NULL);
+		backend_start_update(view, view_get_unique_id(view), userpass, &twitter_item_source, TRUE, update_tweet_view_callback, NULL, NULL);
 		g_free(userpass);
 	}
 	
@@ -517,7 +517,7 @@ static void update_tweet_view(View* view) {
 	g_free(password);
 }
 
-static gboolean update_tweet_view_callback(ViewAddingSession* session, JsonObject* feed, Http* http, time_t delta, gpointer user_data) {
+static gboolean update_tweet_view_callback(ViewAddingSession* session, JsonObject* feed, MicrofeedHttp* http, time_t delta, gpointer user_data) {
 	gchar* referred_unique_id;
 	JsonObject* stream;
 	JsonObject* json;
@@ -539,7 +539,7 @@ static void update_user_view(View* view) {
 	if ((name = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_NAME, NULL)) && *name &&
 	    (password = gconf_client_get_string(gconf, MAUKU_GCONF_KEY_TWITTER_PASSWORD, NULL)) && *password) {
 		userpass = g_strdup_printf("%s:%s", name, password);
-		backend_start_update(view, view_get_unique_id(view), userpass, &twitter_item_source, TRUE, update_generic_view_callback, NULL);
+		backend_start_update(view, view_get_unique_id(view), userpass, &twitter_item_source, TRUE, update_generic_view_callback, NULL, NULL);
 		g_free(userpass);
 	}
 	
